@@ -28,7 +28,7 @@ function (x=mycor, n_factors, rotate=c("promax", "varimax", "none"),
   # cor matrix:  mycor as class out_all, mycor$R, or stand-alone matrix
   cor.nm <- deparse(substitute(x))
   .cor.exists(cor.nm)  # see if matrix exists in one of the 3 locations
-  if (class(x) == "out_all")
+  if ("out_all" %in% class(x))  # R 4.0 results in two values: matrix, array
     x <- eval(parse(text=paste(cor.nm, "$R", sep="")))  # go to $R 
     
 
